define(
//begin v1.x content
({
	insertAnchor: "插入锚点",
	title: "锚点属性",
	anchor: "名称：",
	text: "描述：",
	set: "设置",
	cancel: "取消"
})
//end v1.x content
);
